@@ -12,9 +12,7 @@ CASTLE_TOP_MAX_ROW = 2
 CASTLE_BOT_MIN_ROW = 7
 CASTLE_BOT_MAX_ROW = 9
 
-CASTLE_TOP_SOLDIER_EXCEPTION_LEFT = (2, 3)
-CASTLE_TOP_SOLDIER_EXCEPTION_RIGHT = (2, 5)
-CASTLE_BOT_SOLDIER_EXCEPTION_LEFT = (7, 3)
-CASTLE_BOT_SOLDIER_EXCEPTION_RIGHT = (7, 5)
+CASTLE_TOP_CENTER = (1, 4)
+CASTLE_BOT_CENTER = (8, 4)
 
 HAN_ADVANTAGE = 1.5
